==> BuyseTest_3.0.2.tar.gz: BuyseTest/R/1-setGeneric.R <==
## * Allocator alloc (for BuyseTest-options)
setGeneric(name = "alloc", 
           def = function(object, ...){standardGeneric("alloc")}
)

## * Selector select (for BuyseTest-options)
setGeneric(name = "select", 
           def = function(object, ...){standardGeneric("select")}
)

## * Selector getCount (for S4BuyseTest)
#' @rdname S4BuyseTest-getCount
#' @exportMethod getCount
#' @keywords methods
setGeneric(name = "getCount",
           def = function(object, type){standardGeneric("getCount")}
)

## * Selector getPairScore (for S4BuyseTest)
#' @rdname S4BuyseTest-getPairScore
#' @exportMethod getPairScore
#' @keywords methods
setGeneric(name = "getPairScore",
           def = function(object, endpoint = NULL, strata = NULL, sum = FALSE,
                          rm.withinStrata = TRUE, rm.strata = is.na(object@strata),
                          rm.indexPair = TRUE, rm.weight = FALSE, rm.corrected = (object@correction.uninf==0),
                          unlist = TRUE, trace = 1){
               standardGeneric("getPairScore")
           }
           )

## * Selector getPseudovalue (for S4BuyseTest)
#' @rdname S4BuyseTest-getPseudovalue
#' @exportMethod getPseudovalue
#' @keywords methods
setGeneric(name = "getPseudovalue",
           def = function(object, statistic = NULL, endpoint = NULL){
               standardGeneric("getPseudovalue")
           }
)

## * Selector getSurvival (for S4BuyseTest)
#' @rdname S4BuyseTest-getSurvival
#' @exportMethod getSurvival
#' @keywords methods 
setGeneric(name = "getSurvival",
           def = function(object, type = NULL, endpoint = NULL, strata = NULL, unlist = TRUE, trace = TRUE){
               standardGeneric("getSurvival")
           }
)

## * Selector getIid (for S4BuyseTest)
#' @rdname S4BuyseTest-getIid
#' @exportMethod getIid
#' @keywords methods
setGeneric(name = "getIid",
           def = function(object, endpoint = NULL, statistic = NULL, strata = FALSE, cumulative = TRUE, center = TRUE, scale = TRUE, type = "all", cluster = NULL, simplify = FALSE){
               standardGeneric("getIid")
           }
)

## * method sensitivity (for BuyseTest)
#' @rdname S4BuyseTest-sensitivity
#' @exportMethod sensitivity
#' @keywords htest
setGeneric(name = "sensitivity", 
           def = function(object, ...){standardGeneric("sensitivity")}
)

==> BuyseTest_3.0.4.tar.gz: BuyseTest/R/1-setGeneric.R <==
## * Allocator alloc (for BuyseTest-options)
setGeneric(name = "alloc", 
           def = function(object, ...){standardGeneric("alloc")}
)

## * Selector select (for BuyseTest-options)
setGeneric(name = "select", 
           def = function(object, ...){standardGeneric("select")}
)

## * Selector getCount (for S4BuyseTest)
#' @rdname S4BuyseTest-getCount
#' @exportMethod getCount
#' @keywords methods
setGeneric(name = "getCount",
           def = function(object, type){standardGeneric("getCount")}
)

## * Selector getPairScore (for S4BuyseTest)
#' @rdname S4BuyseTest-getPairScore
#' @exportMethod getPairScore
#' @keywords methods
setGeneric(name = "getPairScore",
           def = function(object, endpoint = NULL, strata = NULL, cumulative = FALSE,
                          rm.withinStrata = TRUE, rm.strata = is.na(object@strata),
                          rm.indexPair = TRUE, rm.weight = FALSE, rm.corrected = (object@correction.uninf==0),
                          unlist = TRUE, trace = 1){
               standardGeneric("getPairScore")
           }
           )

## * Selector getPseudovalue (for S4BuyseTest)
#' @rdname S4BuyseTest-getPseudovalue
#' @exportMethod getPseudovalue
#' @keywords methods
setGeneric(name = "getPseudovalue",
           def = function(object, statistic = NULL, endpoint = NULL){
               standardGeneric("getPseudovalue")
           }
)

## * Selector getSurvival (for S4BuyseTest)
#' @rdname S4BuyseTest-getSurvival
#' @exportMethod getSurvival
#' @keywords methods 
setGeneric(name = "getSurvival",
           def = function(object, type = NULL, endpoint = NULL, strata = NULL, unlist = TRUE, trace = TRUE){
               standardGeneric("getSurvival")
           }
)

## * Selector getIid (for S4BuyseTest)
#' @rdname S4BuyseTest-getIid
#' @exportMethod getIid
#' @keywords methods
setGeneric(name = "getIid",
           def = function(object, endpoint = NULL, statistic = NULL, strata = FALSE, cumulative = TRUE, center = TRUE, scale = TRUE, type = "all", cluster = NULL, simplify = FALSE){
               standardGeneric("getIid")
           }
)

## * method sensitivity (for BuyseTest)
#' @rdname S4BuyseTest-sensitivity
#' @exportMethod sensitivity
#' @keywords htest
setGeneric(name = "sensitivity", 
           def = function(object, ...){standardGeneric("sensitivity")}
)
